#!/bin/csh -f
# 
# NAME: 	merging_epic_spectra_fromspectra.csh
# AUTHOR:	Matteo Guainazzi (XMM-Newton/SOC)
# VERSIONS: 	1.0   - 29 Apr 2010
#               1.0.1 - 29 Jun 2010 - Spectra are used as input
#                                   (from "merging_epic_spectra_fromevlists.csh")
#               1.1   - 30 Jul 2010 - ARF and RMS are multipled before merging
#               
# PURPOSE:	This script generate spectra from the three EPIC cameras with
#               a commong binning, the associate response files, and merge
#               them together into a single source+background, background
#               spectrum file, redistribution matrix and effective area
#               vector
#
# INPUTS:       For each of the three EPIC cameras (MOS1, MOS2, pn):
#               - and event list
#               - a spatial selection expression for the source+background
#                 spectrum
#               - a spatial selection expression for the background spectrum
#
# OUTPUTS:    
#               In the directory: "`pwd`/results":  
#               - "epic_src.pi" -> Combined EPIC source+background spectrum
#               - "epic_bkg.pi" -> Combined EPIC background spectrum
#               - "epic.rmf"    -> Combined redistribution matrix
#               - "epic.arf"    -> Combined effective area
#
# CAVEATS:
#               * This C-shell script has been written by an astronomer, not
#                 by a professional programmer. Handling of condition errors,
#                 consistency checks on te presence of files ... everything
#                 is rather home-made
#               * Provisionally, the selection expressions are read from text
#                 files, because that's the format they come from the XCAL
#               * It is assumed that users wants to extract spectra from
#                 standard PATTERN selections in all the cameras. To modify
#                 this, users must change the definition of the following
#                 variables: ${mos1_src_sel}, ${mos1_bkg_sel}, ${mos2_src_sel},
#                 ${mos2_bkg_sel}, ${pn_bkg_sel}, ${pn_src_sel}
#               * At the end the EPIC merged spectrum is grouped. Optional.
#
# REFERENCE:    This script accomplish the task described in the SAS thread:
#        
# http://xmm.esac.esa.int/sas/current/documentation/threads/epic_merging.shtml
#
#
# If number of command line argument < 1 exit
#
# I/O parameters definition
#

set mos1_src_spc = r12_o1_srspec_1.fits
set mos1_bkg_spc = r12_o1_bgspec_1.fits
set mos2_src_spc = r12_o1_srspec_2.fits
set mos2_bkg_spc = r12_o1_bgspec_2.fits
##
#
# Variable definition
#
# PN obs1
set mos1_src_rsp = r12_o1_1.rsp
# PN obs2
set mos2_src_rsp = r12_o1_2.rsp
## PN obs3
set pn_src_rsp = src_PN3.rsp


# PN - 1+2
set mos_src_spc = src_RGS_TOTAL.pha
set mos_bkg_spc = bkg_RGS_TOTAL.pha
set mos_src_rsp = src_RGS_TOTAL.rsp
#
# ******** Combining MOS cameras
#
echo "Combining MOS1 and MOS2"
#
# Summing background spectra
#
echo "Summing background spectra"
fkeypar fitsfile=${mos1_bkg_spc}+1 keyword=BACKSCAL
set mos1_backscal = `pget fkeypar value`
fkeypar fitsfile=${mos1_bkg_spc}+1 keyword=EXPOSURE
set mos1_exposure = `pget fkeypar value`
fkeypar fitsfile=${mos2_bkg_spc}+1 keyword=BACKSCAL
set mos2_backscal = `pget fkeypar value`
fkeypar fitsfile=${mos2_bkg_spc}+1 keyword=EXPOSURE
set mos2_exposure = `pget fkeypar value`
set mos_exposure =  `awk -v e1=${mos1_exposure} -v e2=${mos2_exposure} 'BEGIN {printf"%f", (e1+e2)/2}'`
## Cambia la coma por punto..
set mos_exposure = `echo $mos_exposure | sed s/\\,/./g`

echo "El total exposure es: $mos_exposure"
### Corre de hecho mathpha
mathpha errmeth="Gauss" expr="$mos1_bkg_spc+$mos2_bkg_spc" \
        units=COUNTS outfil=${mos_bkg_spc} exposure=$mos_exposure\
        backscal='NONE' areascal='%' ncomments=0 clobber=yes
set backscal_sum = `awk -v e1=${mos1_backscal} -v e2=${mos2_backscal} 'BEGIN {printf"%f", e1+e2}'`
## Cambia la coma por punto..
set backscal_sum = `echo $backscal_sum | sed s/\\,/./g`
echo "EL backscale es $backscal_sum"

fparkey value=${backscal_sum} fitsfile=${mos_bkg_spc}+1 keyword=BACKSCAL
fparkey value=${mos_exposure} fitsfile=${mos_bkg_spc}+1 keyword=EXPOSURE
fparkey value="RGS" fitsfile=${mos_bkg_spc}+1 keyword=INSTRUME
fparkey value="XMM" fitsfile=${mos_bkg_spc}+1 keyword=TELESCOP

#
# Summing source+background spectra
#
echo "Summing source+background spectra"
fkeypar fitsfile=${mos1_src_spc}+1 keyword=BACKSCAL
set mos1_backscal = `pget fkeypar value`
fkeypar fitsfile=${mos1_src_spc}+1 keyword=EXPOSURE
set mos1_exposure = `pget fkeypar value`
fkeypar fitsfile=${mos2_src_spc}+1 keyword=BACKSCAL
set mos2_backscal = `pget fkeypar value`
fkeypar fitsfile=${mos2_src_spc}+1 keyword=EXPOSURE
set mos2_exposure = `pget fkeypar value`
set mos_exposure =  `awk -v e1=${mos1_exposure} -v e2=${mos2_exposure} 'BEGIN {printf"%f", (e1+e2)/2}'`
## Cambia la coma por punto..
set mos_exposure = `echo $mos_exposure | sed s/\\,/./g`

## Corre..
mathpha errmeth="Gauss" expr="${mos1_src_spc}+${mos2_src_spc}" \
        units=COUNTS outfil=${mos_src_spc} exposure=${mos_exposure} \
        backscal='NONE' areascal='%' ncomments=0 clobber=yes
set backscal_sum = `awk -v e1=${mos1_backscal} -v e2=${mos2_backscal} 'BEGIN {printf"%f", e1+e2}'`
fparkey value=${backscal_sum} fitsfile=${mos_src_spc}+1 keyword=BACKSCAL
fparkey value=${mos_exposure} fitsfile=${mos_src_spc}+1 keyword=EXPOSURE
fparkey value="RGS" fitsfile=${mos_src_spc}+1 keyword=INSTRUME
fparkey value="XMM" fitsfile=${mos_src_spc}+1 keyword=TELESCOP

#
# Summing effective areas
#
echo "Combining effective area and redistribution matrices"
set arf_norm_1 = `awk -v e1="${mos1_exposure}" -v e2="${mos2_exposure}" 'BEGIN {print (2.0/(1.0+(e2/e1)))}'`
set arf_norm_2 = `awk -v e1="${mos1_exposure}" -v e2="${mos2_exposure}" 'BEGIN {print ((2.0*(e2/e1))/(1+(e2/e1)))}'`
## Cambia la coma por punto..
set arf_norm_1 = `echo $arf_norm_1 | sed s/\\,/./g`
set arf_norm_2 = `echo $arf_norm_2 | sed s/\\,/./g`

#
# Summing response matrices
#
echo "Summing redistribution matrices"
addrmf list="${mos1_src_rsp} ${mos2_src_rsp}" \
       weights="${arf_norm_1} ${arf_norm_2}" rmffile=${mos_src_rsp} clobber=yes
fparkey value="RGS" fitsfile=${mos_src_rsp}+1 keyword=INSTRUME
fparkey value="RGS" fitsfile=${mos_src_rsp}+2 keyword=INSTRUME
fparkey value="XMM" fitsfile=${mos_src_rsp}+1 keyword=TELESCOP
fparkey value="XMM" fitsfile=${mos_src_rsp}+2 keyword=TELESCOP
